@@ -10,6 +10,7 @@ import PropTypes from "prop-types";
 import React from "react";
 import { Table } from "semantic-ui-react";
 import isEmpty from "lodash/isEmpty";
+import { i18next } from "@translations/invenio_administration/i18next";
 
 export const SearchResultsContainer = ({
   results,
@@ -32,7 +33,9 @@ export const SearchResultsContainer = ({
               </Table.HeaderCell>
             );
           })}
-          {resourceHasActions && <Table.HeaderCell>Actions</Table.HeaderCell>}
+          {resourceHasActions && (
+            <Table.HeaderCell collapsing>{i18next.t("Actions")}</Table.HeaderCell>
+          )}
         </Table.Row>
       </Table.Header>
       <Table.Body>{results}</Table.Body>
